@@ -47,6 +47,7 @@ rm = gf.remove
 jparser = json.Parser()
 cd = os.chdir
 curdir = os.getcwd
+usrdir = os.path.expanduser("~")
 
 tf = lazy_import('tensorflow')
 TextLineDataset = tf.data.TextLineDataset
@@ -105,6 +106,10 @@ class File(object):
     @classmethod
     def listdir(cls, filepath):
         return listdir(filepath)
+    
+    @classmethod
+    def curdir(cls):
+        return curdir()
 
     @classmethod
     def mkdir(cls, directory):
@@ -118,6 +123,16 @@ class File(object):
     def mkdirs(cls, directory):
         return mkdirs(directory)
     
+    @classmethod
+    def userdir(cls, path=None, *paths, **kwargs):
+        if not path:
+            return usrdir
+        _dir = os.path.join(usrdir, path, *paths)
+        for k in ['mkdir', 'mkdirs', 'makedir', 'makedirs']:
+            if kwargs.get(k):
+                mkdirs(_dir)
+        return _dir
+    
     @classmethod
     def getdir(cls, filepath):
         if 'gs://' not in filepath:
